@@ -33,13 +33,13 @@ class SKGMainPanel;
 class SKGAdvicePlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGAdvicePlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGAdvicePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -72,7 +72,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * The title of the plugin.
@@ -107,7 +107,7 @@ public:
 private Q_SLOTS:
 
 private:
-    Q_DISABLE_COPY(SKGAdvicePlugin);
+    Q_DISABLE_COPY(SKGAdvicePlugin)
 
     SKGDocument* currentDocument;
 
