@@ -52,10 +52,11 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
     ui.kBookmarksList->setPalette(palette);
     ui.kBookmarksList->setRootIsDecorated(false);
     ui.kBookmarksList->setAnimated(false); //Not compatible with double click
-
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
-    //Build contextual menu
+    ui.kTools->setIcon(KIcon("configure"));
+    QTimer::singleShot(200, this, SLOT(initMenu()));
+
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showMenu(QPoint)));
 
@@ -77,6 +78,9 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
     connect(m_modelview, SIGNAL(afterReset()), ui.kBookmarksList, SLOT(resetSelection()));
 
     ui.kBookmarksList->setTextResizable(false);
+
+    //Refresh action states
+    refresh();
 }
 
 SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
@@ -99,9 +103,10 @@ QWidget* SKGBookmarkPluginDockWidget::mainWidget() const
     return ui.kBookmarksList;
 }
 
-void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
+void SKGBookmarkPluginDockWidget::initMenu()
 {
     if (!m_mainMenu) {
+        //Build contextual menu
         m_mainMenu = new KMenu(ui.kBookmarksList);
         QAction* actExpandAll = m_mainMenu->addAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"));
         connect(actExpandAll, SIGNAL(triggered(bool)), ui.kBookmarksList, SLOT(expandAll()));
@@ -142,9 +147,15 @@ void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
 
         m_mainMenu->addSeparator();
         m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("tab_overwritebookmark"));
-    }
 
-    if (m_mainMenu) m_mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
+        ui.kTools->setMenu(m_mainMenu);
+    }
+}
+
+void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
+{
+    initMenu();
+    m_mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
 }
 
 void SKGBookmarkPluginDockWidget::onSetAutostart()
@@ -171,7 +182,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         int nb = selectedBookmarks.count();
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == "Y" ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb);
         for (int i = 0 ; !err && i < nb  ; ++i) {
-            SKGNodeObject bookmark = selectedBookmarks.at(i);
+            SKGNodeObject bookmark(selectedBookmarks.at(i));
             err = bookmark.setAttribute("t_autostart", value);
             if (!err)  err = bookmark.save();
             if (!err)  err = getDocument()->stepForward(i + 1);
@@ -225,7 +236,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
             SKGObjectBase::SKGListSKGObjectBase children;
             selectedNode.getNodes(children);
             foreach(const SKGObjectBase & item, children) {
-                nodes.push_back(item);
+                nodes.push_back(SKGNodeObject(item));
             }
         }
     }
@@ -246,7 +257,7 @@ void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
     QSortFilterProxyModel* proxyModel = (QSortFilterProxyModel*) ui.kBookmarksList->model();
     SKGObjectModelBase* model = (SKGObjectModelBase*) proxyModel->sourceModel();
     if (model) {
-        SKGNodeObject node = model->getObject(proxyModel->mapToSource(index));
+        SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (!node.isFolder()) openBookmark(node);
     }
 }
@@ -257,7 +268,7 @@ void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
     QSortFilterProxyModel* proxyModel = (QSortFilterProxyModel*) ui.kBookmarksList->model();
     SKGObjectModelBase* model = (SKGObjectModelBase*) proxyModel->sourceModel();
     if (model) {
-        SKGNodeObject node = model->getObject(proxyModel->mapToSource(index));
+        SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (node.isFolder()) openBookmark(node);
     }
 }
@@ -272,7 +283,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
         QString name;
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) {
-            SKGNodeObject parentNode = bookmarks.at(0);
+            SKGNodeObject parentNode(bookmarks.at(0));
             if (!parentNode.isFolder()) {
                 //This is not a folder, we have to take the parent
                 SKGNodeObject parentNodeTmp;
@@ -309,7 +320,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
         QString name;
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) {
-            SKGNodeObject parentNode = bookmarks.at(0);
+            SKGNodeObject parentNode(bookmarks.at(0));
             if (!parentNode.isFolder()) {
                 //This is not a folder, we have to take the parent
                 SKGNodeObject parentNodeTmp;
@@ -350,7 +361,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
     SKGNodeObject node;
     {
         //Get current selection
-        SKGNodeObject parentNode;
+        SKGNodeObject parentNode(getDocument(), 0);
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         if (bookmarks.count()) parentNode = bookmarks.at(0);
 
@@ -365,7 +376,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, const SKGNodeObject& iParentNode, SKGNodeObject& oCreatedNode) const
+SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, const SKGNodeObject& iParentNode, SKGNodeObject& oCreatedNode)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::createNodeFromPage");
     SKGError err;
@@ -397,8 +408,8 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         name += defaultName;
 
         //Create bookmark
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err);
-        err = SKGNodeObject::createPathNode(getDocument(), name, oCreatedNode, true);
+        SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err);
+        err = SKGNodeObject::createPathNode(iParentNode.getDocument(), name, oCreatedNode, true);
         if (!err) {
             QString value = SKGServices::stringToCsv(iPage->objectName()) % ';' %
                             SKGServices::stringToCsv(defaultName) % ';' %
@@ -436,7 +447,7 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
 
     SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
     if (bookmarks.count() == 1) {
-        SKGNodeObject node = bookmarks.at(0);
+        SKGNodeObject node(bookmarks.at(0));
         KIconDialog diag(this);
         QString icon = diag.openDialog();
         if (!icon.isEmpty()) {
@@ -465,7 +476,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
         int nb = bookmarks.count();
         for (int i = 0; i < nb && !err; ++i) {
-            SKGNodeObject node = bookmarks.at(i);
+            SKGNodeObject node(bookmarks.at(i));
             err = node.remove();
         }
     }
@@ -497,7 +508,7 @@ void SKGBookmarkPluginDockWidget::refresh()
     SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
     int nbSelectedObjects = bookmarks.count();
     if (nbSelectedObjects == 1) {
-        SKGNodeObject node = bookmarks.at(0);
+        SKGNodeObject node(bookmarks.at(0));
         if (m_actSetAutostart) m_actSetAutostart->setEnabled(node.getAttribute("t_autostart") != "Y");
         if (m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(node.getAttribute("t_autostart") == "Y");
     } else {
