@@ -53,7 +53,7 @@ K_PLUGIN_FACTORY(SKGFilePluginFactory, registerPlugin<SKGFilePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGFilePluginFactory("skg_file", "skg_file"))
 
-SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_recentFiles(NULL)
 {
     SKGTRACEIN(10, "SKGFilePlugin::SKGFilePlugin");
 
