@@ -32,13 +32,13 @@ class KAction;
 class SKGHighlightPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGHighlightPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -83,10 +83,10 @@ public:
     virtual int getOrder() const;
 
 private Q_SLOTS:
-    void actionSwitchHighLight();
+    void onSwitchHighLight();
 
 private:
-    Q_DISABLE_COPY(SKGHighlightPlugin);
+    Q_DISABLE_COPY(SKGHighlightPlugin)
 
     SKGDocument* m_currentDocument;
 
