@@ -46,7 +46,7 @@ K_PLUGIN_FACTORY(SKGMonthlyPluginFactory, registerPlugin<SKGMonthlyPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGMonthlyPluginFactory("skg_monthly", "skg_monthly"))
 
-SKGMonthlyPlugin::SKGMonthlyPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGMonthlyPlugin::SKGMonthlyPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGMonthlyPlugin::SKGMonthlyPlugin");
 }
@@ -98,7 +98,7 @@ void SKGMonthlyPlugin::refreshMainPage()
     } else {
         if (m_currentBankDocument) {
             SKGReport* rep = m_currentBankDocument->getReport();
-            SKGError err = rep->getReportFormTemplate(rep, templateFile, html);
+            SKGError err = rep->getReportFromTemplate(rep, templateFile, html);
             if (err) html += err.getFullMessageWithHistorical();
             delete rep;
         }
