@@ -43,7 +43,7 @@ K_PLUGIN_FACTORY(SKGPrintPluginFactory, registerPlugin<SKGPrintPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGPrintPluginFactory("skg_print", "skg_print"))
 
-SKGPrintPlugin::SKGPrintPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGPrintPlugin::SKGPrintPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGPrintPlugin::SKGPrintPlugin");
 }
@@ -66,11 +66,11 @@ bool SKGPrintPlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_print/skg_print.rc");
 
-    m_printAction = KStandardAction::print(this, SLOT(actionPrint()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("print", m_printAction);
+    m_printAction = KStandardAction::print(this, SLOT(onPrint()), actionCollection());
+    registerGlobalAction("print", m_printAction);
 
-    m_printPreviewAction = KStandardAction::printPreview(this, SLOT(actionPrintPreview()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("print_preview", m_printPreviewAction);
+    m_printPreviewAction = KStandardAction::printPreview(this, SLOT(onPrintPreview()), actionCollection());
+    registerGlobalAction("print_preview", m_printPreviewAction);
 
     return true;
 }
@@ -79,7 +79,7 @@ void SKGPrintPlugin::refresh()
 {
     SKGTRACEIN(10, "SKGPrintPlugin::refresh");
     if (m_currentDocument) {
-        bool test = (m_currentDocument->getDatabase() != NULL);
+        bool test = (m_currentDocument->getDatabase() != NULL && SKGMainPanel::getMainPanel()->currentPage() != NULL);
         if (m_printAction) m_printAction->setEnabled(test);
         if (m_printPreviewAction) m_printPreviewAction->setEnabled(test);
     }
@@ -107,10 +107,10 @@ QStringList SKGPrintPlugin::tips() const
     return output;
 }
 
-void SKGPrintPlugin::actionPrint()
+void SKGPrintPlugin::onPrint()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGPrintPlugin::actionPrint", err);
+    SKGTRACEINRC(10, "SKGPrintPlugin::onPrint", err);
 
     if (SKGMainPanel::getMainPanel()) {
         QPrinter printer(QPrinter::HighResolution);
@@ -124,10 +124,10 @@ void SKGPrintPlugin::actionPrint()
     }
 }
 
-void SKGPrintPlugin::actionPrintPreview()
+void SKGPrintPlugin::onPrintPreview()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGPrintPlugin::actionPrintPreview", err);
+    SKGTRACEINRC(10, "SKGPrintPlugin::onPrintPreview", err);
     QPointer<QPrintPreviewDialog> dialog = new QPrintPreviewDialog(SKGMainPanel::getMainPanel());
     connect(dialog, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
     dialog->exec();
