@@ -141,7 +141,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
             QString table = sels.at(0).getRealTable();
             SKGStringListList listTmp;
             m_currentDocument->executeSelectSqliteOrder(
-                "SELECT t_name, t_value FROM (SELECT t_name, t_value, COUNT(1) AS nb FROM parameters WHERE t_uuid_parent like '%-" % table % "' GROUP BY t_name, t_value) ORDER BY nb DESC LIMIT 7",
+                "SELECT t_name, t_value FROM (SELECT t_name, t_value, COUNT(1) AS nb FROM parameters WHERE t_uuid_parent like '%-" % table % "' AND t_name NOT LIKE 'SKG_%' GROUP BY t_name, t_value) ORDER BY nb DESC LIMIT 7",
                 listTmp);
             int nb = listTmp.count();
             for (int i = 1; i < nb; ++i) {
