@@ -55,7 +55,7 @@ private Q_SLOTS:
     void onClearHistory();
 
 private:
-    Q_DISABLE_COPY(SKGUndoRedoPluginDockWidget);
+    Q_DISABLE_COPY(SKGUndoRedoPluginDockWidget)
 
     Ui::skgundoredoplugindockwidget_base ui;
 };
