@@ -196,7 +196,7 @@ SKGError SKGImportPluginBackend::importFile()
                         err = SKGError(ERR_FAIL, i18nc("Error message", "No accounts downloaded with the following command:\n%1\nCheck your backend installation.", properties["getoperations"]));
                     } else {
                         //Warning
-                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Warning: Some accounts have not been downloaded"));
+                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded"), SKGDocument::Warning);
                     }
                 }
 
@@ -208,7 +208,8 @@ SKGError SKGImportPluginBackend::importFile()
 
                     //Get all messages
                     QStringList messages;
-                    if (!err) err = m_importer->getDocument()->getMessages(m_importer->getDocument()->getCurrentTransaction(), messages, true);
+                    QList<SKGDocument::MessageType> types;
+                    if (!err) err = m_importer->getDocument()->getMessages(m_importer->getDocument()->getCurrentTransaction(), messages, types, true);
 
                     //Import all files
                     for (int i = 0; !err && i < nb; ++i) {
@@ -236,8 +237,9 @@ SKGError SKGImportPluginBackend::importFile()
 
                     //Reset message
                     if (!err) err = m_importer->getDocument()->removeMessages(m_importer->getDocument()->getCurrentTransaction());
-                    foreach(const QString & msg, messages)
-                    m_importer->getDocument()->sendMessage(msg);
+                    int nbm = messages.count();
+                    for (int j = 0; j < nbm; ++j)
+                        m_importer->getDocument()->sendMessage(messages.at(j), types.at(j));
 
                     if (!err) err = m_importer->getDocument()->setParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE", SKGServices::dateToSqlString(QDateTime::currentDateTime()));
                     if (!err) err = m_importer->getDocument()->setParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST", currentList);
