@@ -598,7 +598,7 @@ SKGError SKGImportPluginCsv::importFile()
                                 //Update account
                                 if (!err) err = defAccount.setInitialBalance(SKGServices::stringToDouble(balance) - currentAmount, defUnit);
                                 if (!err) err = defAccount.save();
-                                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()));
+                                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()), SKGDocument::Warning);
 
                             } else m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
                         }
