@@ -84,7 +84,7 @@ SKGError SKGImportPluginKmy::importFile()
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QDomDocument doc;
 
@@ -99,7 +99,7 @@ SKGError SKGImportPluginKmy::importFile()
             err.setReturnCode(ERR_ABORT);
             err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
 
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         } else {
             //Get root
             QDomElement docElem = doc.documentElement();
@@ -363,15 +363,16 @@ SKGError SKGImportPluginKmy::importFile()
                             if (!err) err = operationObj.setUnit(unit);
                         }
                     }
-                    if (!err) err = operationObj.save();
+                    if (!err) err = operationObj.save(false, false);
 
                     //Is it a schedule ?
                     if (!err) {
                         QDomElement recu = operation.parentNode().toElement();
                         if (recu.tagName() == "SCHEDULED_TX") {
                             //Yes ==> creation of the schedule
+                            if (!err) err = operationObj.load();
                             if (!err) err = operationObj.setTemplate(true);
-                            if (!err) err = operationObj.save();
+                            if (!err) err = operationObj.save(true, false);
 
                             //Yes ==> creation of the schedule
                             SKGRecurrentOperationObject recuObj;
@@ -540,7 +541,7 @@ SKGError SKGImportPluginKmy::importFile()
                         }
                     }
 
-                    if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
 
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
@@ -554,9 +555,20 @@ SKGError SKGImportPluginKmy::importFile()
             QDomElement budgets = docElem.firstChildElement("BUDGETS");
             if (!err && !budgets.isNull()) {
                 SKGTRACEINRC(10, "SKGImportExportManager::importKMY-BUDGETS", err);
+                //Build cache of categories
+                QMap<int, bool> catExpense;
+                {
+                    SKGStringListList list;
+                    err = m_importer->getDocument()->executeSelectSqliteOrder("SELECT id, t_TYPEEXPENSE FROM v_category_display", list);
+                    int nb = list.count();
+                    for (int i = 1; i < nb; ++i) {
+                        catExpense[SKGServices::stringToInt(list.at(i).at(0))] = (list.at(i).at(0) == "-");
+                    }
+                }
+
                 QDomNodeList budgetList = budgets.elementsByTagName("BUDGET");
                 int nb = budgetList.count();
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import budgets"), nb);
+                if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import budgets"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     QDomElement budget = budgetList.at(i).toElement();
                     QDomNodeList accountList = budget.elementsByTagName("ACCOUNT");
@@ -576,9 +588,8 @@ SKGError SKGImportPluginKmy::importFile()
                             if (vals.count() == 1) q = SKGServices::stringToDouble(vals.at(0));
                             else if (vals.count() == 2) q = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
 
-                            SKGObjectBase cat2(cat.getDocument(), "v_category_display", cat.getID());
                             //Are we able to find to sign with the category ?
-                            if (cat2.getAttribute("t_TYPEEXPENSE") == "-") q = -q;
+                            if (catExpense[cat.getID()]) q = -q;
 
                             QStringList dates = SKGServices::splitCSVLine(period.attribute("start"), '-');
                             if (dates.count() == 3) {
@@ -632,7 +643,7 @@ SKGError SKGImportPluginKmy::importFile()
 bool SKGImportPluginKmy::isExportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "KMY");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "KMY");
 }
 
 SKGError SKGImportPluginKmy::exportFile()
@@ -645,10 +656,10 @@ SKGError SKGImportPluginKmy::exportFile()
     SKGTRACEINRC(2, "SKGImportPluginKmy::exportFile", err);
 
     //Open file
-    QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
+    QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(false), "application/x-gzip");
     if (!file->open(QIODevice::WriteOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QDomDocument doc("KMYMONEY-FILE");
         QDomComment comment = doc.createComment("Generated by libskgbankmodeler");
