@@ -39,7 +39,7 @@ class QDomElement;
 class SKGImportPluginKmy : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -87,7 +87,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginKmy);
+    Q_DISABLE_COPY(SKGImportPluginKmy)
 
     static SKGError exportOperation(const SKGOperationObject& iOperation, QDomDocument& iDoc, QDomElement& iTransaction);
     static QString kmyValue(double iValue);
