@@ -59,7 +59,7 @@ SKGImportPluginMmb::~SKGImportPluginMmb()
 bool SKGImportPluginMmb::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginMmb::isImportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "MMB");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "MMB");
 }
 
 SKGError SKGImportPluginMmb::importFile()
