@@ -165,7 +165,7 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
         SKGImportPluginOfx::m_ofxError = getAccount(accountData, doc, act);
         if (!SKGImportPluginOfx::m_ofxError) {
             if (act.getNbOperation() > 1) {
-                SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", act.getName()));
+                SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", act.getName()), SKGDocument::Warning);
             } else {
                 m_ofxInitialBalance.push_back(data);
             }
@@ -336,6 +336,81 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         if (!SKGImportPluginOfx::m_ofxError && data.memo_valid == true) SKGImportPluginOfx::m_ofxError = ope.setComment(QString::fromUtf8(data.memo));
         if (!SKGImportPluginOfx::m_ofxError && data.check_number_valid == true) SKGImportPluginOfx::m_ofxError = ope.setNumber(SKGServices::stringToInt(data.check_number));
         if (!SKGImportPluginOfx::m_ofxError && data.invtransactiontype_valid == true) SKGImportPluginOfx::m_ofxError = ope.setMode(i18nc("Noun, the title of an item", "Title"));
+        if (!SKGImportPluginOfx::m_ofxError && data.transactiontype_valid == true) {
+            QString mode;
+            switch (data.transactiontype) {
+            case OFX_CREDIT: {
+                mode = i18nc("Noun, type of OFX transaction", "Credit");
+                break;
+            }
+            case OFX_DEBIT: {
+                mode = i18nc("Noun, type of OFX transaction", "Debit");
+                break;
+            }
+            case OFX_INT: {
+                mode = i18nc("Noun, type of OFX transaction", "Interest");
+                break;
+            }
+            case OFX_DIV: {
+                mode = i18nc("Noun, type of OFX transaction", "Dividend");
+                break;
+            }
+            case OFX_FEE: {
+                mode = i18nc("Noun, type of OFX transaction", "FI fee");
+                break;
+            }
+            case OFX_SRVCHG: {
+                mode = i18nc("Noun, type of OFX transaction", "Service charge");
+                break;
+            }
+            case OFX_DEP: {
+                mode = i18nc("Noun, type of OFX transaction", "Deposit");
+                break;
+            }
+            case OFX_ATM: {
+                mode = i18nc("Noun, type of OFX transaction", "ATM");
+                break;
+            }
+            case OFX_POS: {
+                mode = i18nc("Noun, type of OFX transaction", "Point of sale");
+                break;
+            }
+            case OFX_XFER: {
+                mode = i18nc("An operation mode", "Transfer");
+                break;
+            }
+            case OFX_CHECK: {
+                mode = i18nc("An operation mode", "Check");
+                break;
+            }
+            case OFX_PAYMENT: {
+                mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
+                break;
+            }
+            case OFX_CASH: {
+                mode = i18nc("An operation mode", "Withdrawal");
+                break;
+            }
+            case OFX_DIRECTDEP: {
+                mode = i18nc("Noun, type of OFX transaction", "Deposit");
+                break;
+            }
+            case OFX_DIRECTDEBIT: {
+                mode = i18nc("An operation mode", "Direct debit");
+                break;
+            }
+            case OFX_REPEATPMT: {
+                mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
+                break;
+            }
+            case OFX_OTHER: {
+                mode = "";
+                break;
+            }
+            }
+
+            SKGImportPluginOfx::m_ofxError = ope.setMode(mode);
+        }
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.save();
 
         //Create sub operation
