@@ -31,7 +31,7 @@
 class SKGImportPluginOfx : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -66,7 +66,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginOfx);
+    Q_DISABLE_COPY(SKGImportPluginOfx)
 
     static int ofxAccountCallback(struct OfxAccountData data, void* pv);
     static int ofxTransactionCallback(struct OfxTransactionData data, void* pv);
