@@ -741,7 +741,7 @@ SKGError SKGImportPluginQif::importFile()
                             QString checkOperationAmountString = SKGServices::doubleToString(checkOperationAmount);
                             QString checkSuboperationsAmountString = SKGServices::doubleToString(checkSuboperationsAmount);
                             if (!err && checkOperationAmount != 0 && checkSuboperationsAmount != 0 && checkOperationAmountString != checkSuboperationsAmountString) {
-                                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Warning: The total amount of the operation (%1) is different to the sum of the sub-operations (%2).", checkOperationAmountString, checkSuboperationsAmountString));
+                                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "The total amount of the operation (%1) is different to the sum of the sub-operations (%2).", checkOperationAmountString, checkSuboperationsAmountString), SKGDocument::Warning);
                             }
 
                             //Initialize variables
