@@ -57,7 +57,7 @@ SKGImportPluginXhb::~SKGImportPluginXhb()
 bool SKGImportPluginXhb::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginXhb::isImportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "XHB");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "XHB");
 }
 
 SKGError SKGImportPluginXhb::importFile()
@@ -71,7 +71,7 @@ SKGError SKGImportPluginXhb::importFile()
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QDomDocument doc;
 
@@ -92,7 +92,7 @@ SKGError SKGImportPluginXhb::importFile()
 
 
         if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "XHB"), 4);
 
@@ -334,7 +334,7 @@ SKGError SKGImportPluginXhb::importFile()
                             }
                         }
 
-                        if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
