@@ -110,7 +110,7 @@ private Q_SLOTS:
     void onSelectedInterestChanged();
 
 private:
-    Q_DISABLE_COPY(SKGCalculatorPluginWidget);
+    Q_DISABLE_COPY(SKGCalculatorPluginWidget)
     void computeInterest();
 
     Ui::skgcalculatorplugin_base ui;
