@@ -30,15 +30,16 @@
 #include <QDomDocument>
 
 SKGInterestBoardWidget::SKGInterestBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument)
+    : SKGBoardWidget(iDocument, i18nc("Title of a dashboard widget", "Estimated interests"))
 {
     SKGTRACEIN(10, "SKGInterestBoardWidget::SKGInterestBoardWidget");
 
-    ui.setupUi(this);
+    m_label = new QLabel();
+    setMainWidget(m_label);
 
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
-    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
+    connect(m_label, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGInterestBoardWidget::~SKGInterestBoardWidget()
@@ -82,8 +83,8 @@ void SKGInterestBoardWidget::dataModified(const QString& iTableName, int iIdTran
                     html += "<table>";
                     double sum = 0;
                     for (int i = 0; i < nb; ++i) {
-                        SKGAccountObject obj = objs.at(i);
-                        html += QString("<tr><td><a href=\"skg://Skrooge_calculator_plugin/?currentPage=0&account=" % KUrl::encode_string(obj.getName()) % "\">") % SKGServices::stringToHtml(obj.getName()) % "</a></td><td align=\"right\">";
+                        SKGAccountObject obj(objs.at(i));
+                        html += QString("<tr><td><a href=\"skg://Skrooge_calculator_plugin/?currentPage=0&account=" % SKGServices::encodeForUrl(obj.getName()) % "\">") % SKGServices::stringToHtml(obj.getName()) % "</a></td><td align=\"right\">";
 
                         QList<SKGAccountObject::SKGInterestItem> oInterestList;
                         double oInterests = 0;
@@ -98,10 +99,10 @@ void SKGInterestBoardWidget::dataModified(const QString& iTableName, int iIdTran
                             "</tr>";
                     html += "</table>";
                 } else {
-                    html += i18nc("A Message for the user about financial interests", "No interest defined for accounts<br>on the <a href=\"skg://Skrooge_calculator_plugin/?currentPage=0\">\"Simulation\"</a> page.");
+                    html += i18nc("A Message for the user about financial interests", "No interest defined for accounts<br>on the <a href=\"%1\">\"Simulation\"</a> page.", "skg://Skrooge_calculator_plugin/?currentPage=0");
                 }
                 html += "</body></html>";
-                ui.kLabel->setText(html);
+                m_label->setText(html);
             }
 
             //No widget if no account
