@@ -310,7 +310,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_categories");
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("clean_delete_unused_categories");
     if (act) act->trigger();
 }
 
