@@ -134,7 +134,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     overlaytransfers.push_back("view-financial-transfer");
 
     m_processingFoundTransfert = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18nc("Verb, action to find and group transfers", "Find and group transfers"), this);
-    connect(m_processingFoundTransfert, SIGNAL(triggered(bool)), SLOT(foundTransfer()));
+    connect(m_processingFoundTransfert, SIGNAL(triggered(bool)), SLOT(findTransfers()));
     processing->addAction(m_processingFoundTransfert);
     m_processingFoundTransfert->setShortcut(Qt::CTRL + Qt::META + Qt::Key_G);
     registerGlobalAction("process_foundtransfer", m_processingFoundTransfert);
@@ -179,7 +179,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     registerGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
 
     //Get last argument
-    connect(this, SIGNAL(importFile(QStringList)), this, SLOT(import(QStringList)), Qt::QueuedConnection);
+    connect(this, SIGNAL(importFileName(QString)), this, SLOT(import(QString)), Qt::QueuedConnection);
 
     //Open/import input file
     int nbArg = iArgument.count();
@@ -206,7 +206,7 @@ void SKGImportExportPlugin::processArguments(const QStringList& iArgument)
     int nbArg = iArgument.count();
     if (nbArg) {
         QString filename = iArgument.at(nbArg - 1);
-        if (QFile(filename).exists()) Q_EMIT importFile(QStringList() << filename);
+        if (QFile(filename).exists()) Q_EMIT importFileName(filename);
     }
 }
 
@@ -222,11 +222,25 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
 
     //Build list of known backends
     QStringList backends;
-    foreach(const QString & file, KStandardDirs().findAllResources("data", KGlobal::mainComponent().aboutData()->appName() % "/backends/*.backend")) {
+    foreach(const QString & file, KStandardDirs().findAllResources("data", "skrooge/backends/*.backend")) {
         backends.push_back(QFileInfo(file).baseName().toLower());
     }
     ui.kbackendText->setText(i18nc("Information", "You must enter the list of backends to use separated by a ';'.\nExample: backendA;backendB.\n\nHere is the list of known backends: %1.", backends.join(";")));
 
+    //Add date formats
+    QStringList dateFormats;
+    dateFormats << i18nc("Format date", "Automatic detection")
+                << "YYYYMMDD"
+                << "MMDDYYYY"
+                << "DDMMYYYY"
+                << "MM-DD-YY"
+                << "DD-MM-YY"
+                << "MM-DD-YYYY"
+                << "DD-MM-YYYY"
+                << "YYYY-MM-DD";
+    ui.kcfg_qif_date_format->addItems(dateFormats);
+    ui.kcfg_csv_date_format->addItems(dateFormats);
+
     return widget;
 }
 
@@ -260,6 +274,8 @@ QStringList SKGImportExportPlugin::tips() const
     output.push_back(i18nc("Description of a tips", "<p>... you can customize your CSV import with regular expressions defined in setting panel.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can export the full content of your document into a XML file.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can apply automatic rules after an import to set the right categories.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>... you can convert file by using the batch tool '%1'.</p>", "skroogeconvert"));
+    output.push_back(i18nc("Description of a tips", "<p>... skrooge uses the name of the imported file to find the target account.</p>"));
     return output;
 }
 
@@ -309,7 +325,7 @@ void SKGImportExportPlugin::importbackends()
             //Is password needed?
             QString pwd;
             QHash< QString, QString > properties;
-            err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/backends/" % backends[i] % ".backend"), properties);
+            err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", "skrooge/backends/" % backends[i] % ".backend"), properties);
             if (!err && (properties["getaccounts"].contains("%3") || properties["getoperations"].contains("%3"))) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
                 QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
@@ -326,7 +342,7 @@ void SKGImportExportPlugin::importbackends()
             if (codec.isEmpty()) codec = QTextCodec::codecForLocale()->name();
             if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
 
-            SKGImportExportManager imp1(m_currentBankDocument, "." % backends[i]);
+            SKGImportExportManager imp1(m_currentBankDocument, KUrl("." % backends[i]));
             QMap<QString, QString> parameters = imp1.getImportParameters();
             parameters["password"] = pwd;
             imp1.setImportParameters(parameters);
@@ -346,12 +362,17 @@ void SKGImportExportPlugin::importbackends()
     if (!err) openLastModifiedIfSetting();
 }
 
-void SKGImportExportPlugin::import(const QStringList& iFiles)
+void SKGImportExportPlugin::import(const QString& iFile)
+{
+    import(QList<KUrl>() << KUrl::fromLocalFile(iFile));
+}
+
+void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportPlugin::import", err);
     if (m_currentBankDocument) {
-        QList<QString> fileNames;
+        QList<KUrl> fileNames;
         QString lastCodecUsed = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
         if (lastCodecUsed.isEmpty()) lastCodecUsed = QTextCodec::codecForLocale()->name();
         QString codec;
@@ -362,11 +383,13 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
                                                  sender() == m_importCsvUnitAction ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
                                                  SKGImportExportManager::getImportMimeTypeFilter(),
                                                  SKGMainPanel::getMainPanel());
-            fileNames = result.URLs.toStringList();
+            foreach(const KUrl & url, result.URLs) {
+                fileNames.append(KUrl(url.url()));
+            }
             codec = result.encoding;
         } else {
             fileNames = iFiles;
-            QString codec = lastCodecUsed;
+            codec = lastCodecUsed;
         }
 
         int nbFiles = fileNames.count();
@@ -383,7 +406,7 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
 
                 for (int i = 0; !err && i < nbFiles; ++i) {
                     //Get Filename
-                    QString fileName = fileNames.at(i);
+                    KUrl fileName = fileNames.at(i);
 
                     //Import
                     SKGImportExportManager imp1(m_currentBankDocument, fileName);
@@ -392,7 +415,7 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
                     imp1.setSinceLastImportDate(since_last);
                     imp1.setCodec(codec);
 
-                    if (QFileInfo(fileName).suffix().toUpper() == "CSV") { //TODO: Better
+                    if (QFileInfo(fileName.path()).suffix().toUpper() == "CSV") { //TODO: Better
                         QMap<QString, QString> parameters = imp1.getImportParameters();
 
                         parameters["automatic_search_header"] = (skgimportexport_settings::automatic_search_header() ? "Y" : "N");
@@ -419,6 +442,15 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
                         parameters["automatic_search_columns"] = (skgimportexport_settings::automatic_search_columns() ? "Y" : "N");
                         parameters["columns_positions"] = skgimportexport_settings::columns_positions();
                         parameters["mode_csv_unit"] = (sender() == m_importCsvUnitAction ? "Y" : "N");
+                        parameters["date_format"] = skgimportexport_settings::csv_date_format();
+                        if (parameters["date_format"] == i18nc("Format date", "Automatic detection")) parameters["date_format"] = "";
+
+                        imp1.setImportParameters(parameters);
+                    } else if (QFileInfo(fileName.path()).suffix().toUpper() == "QIF") { //TODO: Better
+                        QMap<QString, QString> parameters = imp1.getImportParameters();
+
+                        parameters["date_format"] = skgimportexport_settings::qif_date_format();
+                        if (parameters["date_format"] == i18nc("Format date", "Automatic detection")) parameters["date_format"] = "";
 
                         imp1.setImportParameters(parameters);
                     }
@@ -429,7 +461,7 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
                         QString additionalMessage;
                         do {
                             //Reset error
-                            err = SKGError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName));
+                            err = SKGError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName.prettyUrl()));
                             pwd = "";
 
                             //Use password dialog
@@ -462,7 +494,7 @@ void SKGImportExportPlugin::import(const QStringList& iFiles)
                     }
 
                     if (err) {
-                        err.addError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName));
+                        err.addError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName.prettyUrl()));
                     }
 
                     if (!err) err = m_currentBankDocument->stepForward(i + 1);
@@ -531,10 +563,10 @@ void SKGImportExportPlugin::anonymize()
     }
 }
 
-void SKGImportExportPlugin::foundTransfer()
+void SKGImportExportPlugin::findTransfers()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportPlugin::foundTransfer", err);
+    SKGTRACEINRC(10, "SKGImportExportPlugin::findTransfers", err);
     if (m_currentBankDocument) {
         int NbOperationsMerged = 0;
         {
