@@ -135,7 +135,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     //------------
     m_openLastModified = new KAction(KIcon("view-refresh", NULL, overlayopen), i18nc("Verb", "Open last modified..."), this);
     m_openLastModified->setData(QString("skg://skrooge_operation_plugin/?title_icon=view-refresh&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations modified or created during last action")) %
-                                        "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT i_object_id FROM doctransactionitem di, doctransaction dt WHERE dt.t_mode='U' AND dt.id=di.rd_doctransaction_id AND di.t_object_table='operation'AND NOT EXISTS(select 1 from doctransaction B where B.i_parent=dt.id))")));
+                                        "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT i_object_id FROM doctransactionitem di, doctransaction dt WHERE dt.t_mode='U' AND +di.rd_doctransaction_id=dt.id AND di.t_object_table='operation'AND NOT EXISTS(select 1 from doctransaction B where B.i_parent=dt.id))")));
     connect(m_openLastModified, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     m_openLastModified->setShortcut(Qt::META + Qt::Key_L);
     registerGlobalAction("view_open_last_modified", m_openLastModified);
@@ -200,7 +200,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     //------------
     actTmp = new KAction(KIcon("draw-freehand", NULL, overlayrun), i18nc("Verb", "Align comment of suboperations"), this);
     connect(actTmp, SIGNAL(triggered(bool)), this, SLOT(onAlignComment()));
-    registerGlobalAction("tool_align_comment", actTmp);
+    registerGlobalAction("clean_align_comment", actTmp);
 
     //------------
     actTmp = new KAction(KIcon("view-financial-transfer", NULL, overlayopen), i18nc("Verb", "Open operations in groups with only one operation..."), this);
@@ -212,7 +212,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     //------------
     actTmp = new KAction(KIcon("view-financial-transfer", NULL, overlayrun), i18nc("Verb", "Remove groups with only one operation."), this);
     connect(actTmp, SIGNAL(triggered(bool)), this, SLOT(onRemoveGroupWithOneOperation()));
-    registerGlobalAction("tool_remove_group_with_one_operation", actTmp);
+    registerGlobalAction("clean_remove_group_with_one_operation", actTmp);
 
     //------------
     m_groupOperation = new KAction(KIcon("view-financial-transfer"), i18nc("Verb", "Group operations"), this);
@@ -285,7 +285,7 @@ SKGBoardWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0) return new SKGOperationBoardWidget(m_currentBankDocument);
     else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                      getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/highlighted_operations.html"),
+                                     KStandardDirs().findResource("data", "skrooge/html/default/highlighted_operations.html"),
                                      QStringList() << "operation");
     return NULL;
 }
@@ -344,6 +344,7 @@ QStringList SKGOperationPlugin::tips() const
     output.push_back(i18nc("Description of a tips", "<p>... you can duplicate an operation including complex operations (split, grouped, ...).</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can create template of operations.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can group and ungroup operations.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>... you have to indicate the sign of an operation only if you want to force it, else it will be determined automatically with the category.</p>"));
     return output;
 }
 
@@ -368,6 +369,7 @@ void SKGOperationPlugin::onGroupOperation()
                 SKGOperationObject operationObj(selection.at(i));
                 if (!err) err = operationObj.setGroupOperation(main);
                 if (!err) err = operationObj.save();
+                if (!err) err = main.load();
 
                 if (!err) err = m_currentBankDocument->stepForward(i + 1);
             }
@@ -882,7 +884,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setLongMessage(i18nc("Advice on making the best (long)", "When a transfer is created and when only one part of this transfer is removed, the second part is in a group of only one operation. This makes no sense."));
             QStringList autoCorrections;
             autoCorrections.push_back("skg://view_open_operation_in_group_of_one");
-            autoCorrections.push_back("skg://tool_remove_group_with_one_operation");
+            autoCorrections.push_back("skg://clean_remove_group_with_one_operation");
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -901,7 +903,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The comment of the operation is not aligned with the comment of the suboperation."));
             QStringList autoCorrections;
             autoCorrections.push_back("skg://view_open_operation_with_comment_not_aligned");
-            autoCorrections.push_back("skg://tool_align_comment");
+            autoCorrections.push_back("skg://clean_align_comment");
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -967,7 +969,7 @@ void SKGOperationPlugin::onRemoveGroupWithOneOperation()
     SKGTRACEINRC(10, "SKGOperationPlugin::onRemoveGroupWithOneOperation", err);
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Remove groups with only one operation"), err);
-        err = m_currentBankDocument->executeSqliteOrder("DELETE FROM operation WHERE operation.i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2");
+        err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET i_group_id=0 WHERE i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2");
     }
 
     //status bar
