@@ -605,7 +605,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
         SKGObjectBase::SKGListSKGObjectBase gops;
         if (!err) err = operationObj.getGroupedOperations(gops);
         if (gops.count() == 2 &&  ui.kWidgetSelector->getSelectedMode() < 2) {
-            getDocument()->sendMessage(i18nc("An information message", "You modified one part of a transfer"));
+            getDocument()->sendMessage(i18nc("An information message", "You modified one part of a transfer"), SKGDocument::Warning);
         }
 
         //Update operation if single selection
@@ -912,7 +912,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                     //Change unit
                     unit = unitTargetAccount;
                 } else {
-                    err = getDocument()->sendMessage(i18nc("Warning message", "Warning: you created an operation in %1 in an account in %2.", unit.getSymbol(), unitTargetAccount.getSymbol()));
+                    err = getDocument()->sendMessage(i18nc("Warning message", "You created an operation in %1 in an account in %2.", unit.getSymbol(), unitTargetAccount.getSymbol()), SKGDocument::Warning);
                 }
                 //Correction bug 283842 ^^^^
             }
