@@ -68,7 +68,7 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
 
     KAction* deleteUnusedPayeesAction = new KAction(KIcon(icon(), NULL, overlaydelete), i18nc("Verb", "Delete unused payees"), this);
     connect(deleteUnusedPayeesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedPayees()));
-    registerGlobalAction("edit_delete_unused_payees", deleteUnusedPayeesAction);
+    registerGlobalAction("clean_delete_unused_payees", deleteUnusedPayeesAction);
 
     return true;
 }
@@ -131,7 +131,7 @@ SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused payees"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing payees for which no operation is registered."));
             QStringList autoCorrections;
-            autoCorrections.push_back("skg://edit_delete_unused_payees");
+            autoCorrections.push_back("skg://clean_delete_unused_payees");
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
