@@ -38,7 +38,9 @@ SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    KAction* open = new KAction(KIcon("skg_open"), i18nc("Verb, open a page", "Open..."), this);
+    QStringList overlayopen;
+    overlayopen.push_back("skg_open");
+    KAction* open = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), this);
     connect(open, SIGNAL(triggered(bool)), this, SLOT(onOpen()));
     addAction(open);
 
