@@ -217,7 +217,7 @@ SKGError SKGScheduledPlugin::savePreferences() const
 
                     if (!err) err = m_currentBankDocument->stepForward(i + 1);
                 }
-                if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"), true);
+                if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"));
             }
         }
     }
@@ -235,7 +235,7 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
         //The selected operation is not a template and settings is set to create one
         operationObjOrig = operationObjDuplicate;
         if (!err) err = operationObjOrig.duplicate(operationObjDuplicate, operationObjOrig.getDate(), true);
-        if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), true);
+        if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), SKGDocument::Positive);
     }
 
     SKGRecurrentOperationObject recOp;
