@@ -86,13 +86,13 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     //Fill combo boxes
     QStringList attributeForQuery;
-    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
+    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_TRANSFER" << "t_UNIT" << "t_ACCOUNT" << "t_TOACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
-    attributeForUpdate << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND";
+    attributeForUpdate << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_ACCOUNT" << "t_REALREFUND" << "t_UNIT";
 
     //Adding properties
     QStringList properties;
-    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation'", properties);
+    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
     for (int i = 0; i < nb; ++i) {
         attributeForQuery.push_back("p_" % properties.at(i));
