@@ -28,12 +28,10 @@
 #include <QDomDocument>
 
 SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument)
+    : SKGBoardWidget(iDocument, i18nc("Title of a dashboard widget", "Quotes"))
 {
     SKGTRACEIN(10, "SKGUnitBoardWidget::SKGUnitBoardWidget");
 
-    ui.setupUi(this);
-
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
@@ -79,9 +77,12 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
     connect(m_menuSharesOwnedOnly, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuSharesOwnedOnly);
 
+    m_label = new QLabel();
+    setMainWidget(m_label);
+
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
-    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
+    connect(m_label, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGUnitBoardWidget::~SKGUnitBoardWidget()
@@ -177,14 +178,14 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                     html += "<table>";
                     QString lastTitle;
                     for (int i = 0; i < nb; ++i) {
-                        SKGUnitObject obj = objs.at(i);
+                        SKGUnitObject obj(objs.at(i));
                         QString type = obj.getAttribute("t_TYPENLS");
                         if (lastTitle != type) {
                             lastTitle = type;
                             html += "<tr><td><b>" % SKGServices::stringToHtml(lastTitle) % "</b></td></tr>";
                         }
                         html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?operationWhereClause=rc_unit_id=" % SKGServices::intToString(obj.getID()) %
-                                        "&title=" % KUrl::encode_string(i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  obj.getName())) %
+                                        "&title=" % SKGServices::encodeForUrl(i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  obj.getName())) %
                                         "&title_icon=view-currency-list&currentPage=-1" % "\">") % SKGServices::stringToHtml(obj.getDisplayName()) % "</a></td><td align=\"right\">";
                         if (obj.getType() == SKGUnitObject::INDEX) primary.Symbol = ' ';
                         html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute("f_CURRENTAMOUNT")), primary);
@@ -195,10 +196,10 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                     }
                     html += "</table>";
                 } else {
-                    html += i18nc("Message about not having any financial Share or financial index in the document", "No share or index defined<br>on the <a href=\"skg://Skrooge_unit_plugin\">\"Units\"</a> page.");
+                    html += i18nc("Message about not having any financial Share or financial index in the document", "No share or index defined<br>on the <a href=\"%1\">\"Units\"</a> page.", "skg://Skrooge_unit_plugin");
                 }
                 html += "</body></html>";
-                ui.kLabel->setText(html);
+                m_label->setText(html);
             }
 
             //No widget if no account
