@@ -34,13 +34,13 @@ class SKGDocumentBank;
 class SKGUnitPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGUnitPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -79,7 +79,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * Must be modified to refresh widgets after a modification.
@@ -138,7 +138,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -147,14 +147,14 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private Q_SLOTS:
-    void actionSplitShare();
+    void onSplitShare();
     void deleteUnusedUnits() const;
 
 private:
-    Q_DISABLE_COPY(SKGUnitPlugin);
+    Q_DISABLE_COPY(SKGUnitPlugin)
 
     SKGDocumentBank* m_currentBankDocument;
     QString m_docUniqueIdentifier;
