@@ -709,8 +709,21 @@ void SKGUnitPluginWidget::activateEditor()
 void SKGUnitPluginWidget::refreshUnitList()
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    //Clean list
     ui.kCurrencyList->clear();
-    ui.kCurrencyList->addItems(SKGUnitObject::getListofKnownCurrencies(ui.kObsolete->isChecked()));
+
+    //Add items
+    QStringList list = SKGUnitObject::getListofKnownCurrencies(ui.kObsolete->isChecked());
+    ui.kCurrencyList->addItems(list);
+
+    //Completion
+    KCompletion* comp = ui.kCurrencyList->completionObject();
+    if (comp) {
+        comp->setIgnoreCase(true);
+        comp->setSoundsEnabled(true);
+        comp->clear();
+        comp->insertItems(list);
+    }
     QApplication::restoreOverrideCursor();
 }
 
