@@ -113,9 +113,12 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
             if (attribute == "t_REALCATEGORY") {
                 realTable = "category";
                 realAtt = "t_fullname";
-            } else if (attribute == "t_ACCOUNT") {
+            } else if (attribute == "t_ACCOUNT" || attribute == "t_TOACCOUNT") {
                 realTable = "account";
                 realAtt = "t_name";
+            } else if (attribute == "t_UNIT") {
+                realTable = "unit";
+                realAtt = "t_name";
             } else if (attribute == "t_REALCOMMENT") {
                 realTable = "suboperation";
                 realAtt = "t_comment";
@@ -192,7 +195,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if (!(!iModeUpdate || attribute.toLower() == attribute) && nb > 1) nb = 1;
+    if (iModeUpdate && attribute == "t_REALCATEGORY" && nb > 1) nb = 1; //TODO: unblock t_REALCATEGORY
     for (int i = 0; i < nb; ++i) {
         QString op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
