@@ -79,7 +79,7 @@ public Q_SLOTS:
 
 
 private:
-    Q_DISABLE_COPY(SKGProcessCreator);
+    Q_DISABLE_COPY(SKGProcessCreator)
 
 
     Ui::skgprocesscreator_base ui;
