@@ -222,7 +222,7 @@ SKGError SKGBudgetObject::process()
                             if (!err) err = setAttribute("f_transferred", SKGServices::doubleToString(transferred));
                             if (!err) err = save();
                         } else {
-                            getDocument()->sendMessage(i18nc("", "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist", rule.getDisplayName(), this->getDisplayName()));
+                            getDocument()->sendMessage(i18nc("", "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist", rule.getDisplayName(), this->getDisplayName()), SKGDocument::Warning);
                         }
                     }
                 }
