@@ -266,7 +266,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
         int nb;
         err = m_document->getNbObjects("v_operation", wc, nb);
         if (!err && nb) {
-            err = m_document->sendMessage(i18np("one operation not imported because it already exists", "%1 operations not imported because they already exists", nb));
+            err = m_document->sendMessage(i18np("one operation not imported because it already exists", "%1 operations not imported because they already exists", nb), SKGDocument::Warning);
 
             //Remove operations imported for nothing
             if (!err) err = m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')');
@@ -301,7 +301,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
 
             //A failure in rule will not block the transaction.
             //A warning message is sent
-            if (err) err = m_document->sendMessage(i18nc("Warning message", "Error during execution of rules:\n%1", err.getFullMessageWithHistorical()));
+            if (err) err = m_document->sendMessage(i18nc("Warning message", "Error during execution of rules:\n%1", err.getFullMessageWithHistorical()), SKGDocument::Error);
         }
 
         //Change imported status
@@ -425,7 +425,7 @@ SKGImportPlugin* SKGImportExportManager::getImportPlugin()
                     m_importPlugin = pluginInterface;
                 }
             } else {
-                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
+                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
             }
         }
     }
@@ -449,7 +449,7 @@ SKGImportPlugin* SKGImportExportManager::getExportPlugin()
                     m_exportPlugin = pluginInterface;
                 }
             } else {
-                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
+                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
             }
         }
     }
