@@ -471,7 +471,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
             if (!err) err = so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount());
             if (!err) err = so1.save();
         }
-        if (!err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), true);
+        if (!err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
     }
 
     //Delete useless operation
