@@ -568,6 +568,7 @@ SKGError SKGUnitObject::getUnitValue(const QDate& iDate, SKGUnitValueObject& oUn
 
 double SKGUnitObject::getAmount(const QDate& iDate) const
 {
+    SKGTRACEIN(10, "SKGUnitObject::getAmount");
     double output = 0;
     if (getType() == SKGUnitObject::PRIMARY) output = 1.0;
     else if (getDocument()) {
@@ -830,7 +831,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     }
                 } else {
                     //283840: doc->sendMessage(KIO::NetAccess::lastErrorString());
-                    doc->sendMessage(i18nc("A warning message", "History for %1 not found on Yahoo", code));
+                    doc->sendMessage(i18nc("A warning message", "History for %1 not found on Yahoo", code), SKGDocument::Warning);
                 }
             }
             if (!err) {
@@ -1022,7 +1023,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     QDate ds;
                     int nb = fields.count();
                     if (nb != unitYahooTitle.count() + 2) {
-                        err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line));
+                        err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line), SKGDocument::Warning);
 
                         if (!err) err = downloadUnitValue(iMode, nbMaxValues, false);
                     } else {
@@ -1046,7 +1047,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                         }
                     }
                 } else {
-                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, errTmp.getFullMessageWithHistorical()));
+                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, errTmp.getFullMessageWithHistorical()), SKGDocument::Warning);
                 }
             }
         } else {
@@ -1108,10 +1109,10 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                     nbLoaded++;
                                 }
                             }
-                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data)); //TODO does not work with html
+                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data), SKGDocument::Warning); //TODO does not work with html
                         }
                     } else {
-                        doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
+                        doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()), SKGDocument::Warning);
                     }
                 }
             }
