@@ -22,7 +22,7 @@
 #include "skgcalculatoreditdesignerplugin.h"
 #include "skgcalculatoredit.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
