@@ -21,7 +21,7 @@
  */
 #include "skgdateedit.h"
 
-#include "kdatevalidator.h"
+#include <kdatevalidator.h>
 #include <klineedit.h>
 #include <kglobal.h>
 #include <klocale.h>
