@@ -20,9 +20,12 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skginterfaceplugin.h"
+#include "skgmainpanel.h"
+
+#include "kactioncollection.h"
 
 SKGInterfacePlugin::SKGInterfacePlugin(QObject* parent)
-    : KParts::Plugin(parent)
+    : KParts::ReadOnlyPart(parent)
 {}
 SKGInterfacePlugin::~SKGInterfacePlugin()
 {}
@@ -36,6 +39,12 @@ void SKGInterfacePlugin::close() {}
 
 void SKGInterfacePlugin::refresh() {}
 
+void SKGInterfacePlugin::registerGlobalAction(const QString& iIdentifier, QAction* iAction)
+{
+    actionCollection()->addAction(iIdentifier, iAction);
+    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction(iIdentifier, iAction, false);
+}
+
 QDockWidget* SKGInterfacePlugin::getDockWidget()
 {
     return NULL;
@@ -57,7 +66,7 @@ QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
 {
     Q_UNUSED(iIndex);
     return NULL;
@@ -113,13 +122,13 @@ bool SKGInterfacePlugin::isEnabled() const
     return true;
 }
 
-SKGAdviceList SKGInterfacePlugin::advice() const
+SKGAdviceList SKGInterfacePlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGAdviceList output;
-    return output;
+    Q_UNUSED(iIgnoredAdvice);
+    return SKGAdviceList();
 }
 
-SKGError SKGInterfacePlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGInterfacePlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     Q_UNUSED(iAdviceIdentifier);
     Q_UNUSED(iSolution);
