@@ -40,7 +40,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGLineEdit(QWidget* parent = 0);
+    explicit SKGLineEdit(QWidget* parent = 0);
 
     /**
      * Default Destructor
