@@ -60,6 +60,7 @@
 #include <klineedit.h>
 #include <kencodingfiledialog.h>
 #include <ktabbar.h>
+#include <kmessagewidget.h>
 
 #ifdef KActivities_FOUND
 #include <KActivities/ResourceInstance>
@@ -103,7 +104,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     QScrollArea* w = new QScrollArea(this);
     w->setFrameShape(QFrame::NoFrame);
     w->setFocusPolicy(Qt::NoFocus);
-    m_mainLayout = new QHBoxLayout(w);
+    m_mainLayout = new QVBoxLayout(w);
     m_mainLayout->setSpacing(0);
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
     m_mainLayout->addWidget(m_tabWidget);
@@ -1024,9 +1025,7 @@ bool SKGMainPanel::queryFileClose()
     SKGTRACEIN(1, "SKGMainPanel::queryFileClose");
     bool output = true;
     if (getDocument()->getCurrentTransaction()) {
-        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-        KMessageBox::information(this, i18nc("Question", "The application cannot be closed when an operation is running."));
-        QApplication::restoreOverrideCursor();
+        displayMessage(i18nc("Question", "The application cannot be closed when an operation is running."), SKGDocument::Error);
         output = false;
     } else if (getDocument()->isFileModified()) {
         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
@@ -1434,7 +1433,7 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
             SKGTRACEL(1) << "opening plugin [" << plugin->objectName() << ']' << endl;
         }
     } else {
-        getDocument()->sendMessage(i18nc("An information message",  "Impossible to open the page because the plugin was not found"));
+        getDocument()->sendMessage(i18nc("An information message",  "Impossible to open the page because the plugin was not found"), SKGDocument::Error);
         notify(); //Due to sendMessage not in a transaction
     }
 
@@ -1601,7 +1600,7 @@ void SKGMainPanel::closePage(QWidget* iWidget, bool iForce)
     SKGTRACEIN(1, "SKGMainPanel::closePage");
     if (getDocument()->getCurrentTransaction()) {
         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-        KMessageBox::information(this, i18nc("Question", "A page cannot be closed when an operation is running."));
+        displayMessage(i18nc("Question", "A page cannot be closed when an operation is running."), SKGDocument::Information);
         QApplication::restoreOverrideCursor();
     } else {
         SKGTabPage* toRemove = qobject_cast< SKGTabPage* >(iWidget);
@@ -1755,21 +1754,61 @@ void SKGMainPanel::notify(int iTransaction)
     SKGObjectBase transaction(getDocument(), "doctransaction", iTransaction);
     if (iTransaction == 0 || transaction.getAttribute("t_mode") != "R") {
         QStringList msg;
-        getDocument()->getMessages(iTransaction, msg, false);
+        QList<SKGDocument::MessageType> type;
+        getDocument()->getMessages(iTransaction, msg, type, false);
         int nbMessages = msg.count();
         if (nbMessages) {
-            //Build message
-            QString message;
+            //Build list of types
+            SKGDocument::MessageType maxType = SKGDocument::Positive;
+            QList<SKGDocument::MessageType> listGroups;
             for (int i = 0; i < nbMessages; ++i) {
-                if (i != 0) message += "<br>";
-                message += msg.at(i);
+                if (listGroups.count() == 0 || type.at(i) != listGroups.at(listGroups.count() - 1)) listGroups.push_back(type.at(i));
+                if ((int) type.at(i) >= (int) maxType) maxType = type.at(i);
             }
 
-            if (nbMessages < 20) {
+            //Is the number of type acceptable?
+            bool modeGrouped = false;
+            if (listGroups.count() > 5 || nbMessages > 20) {
+                //Too many group ==> simplification
+                listGroups.clear();
+                listGroups.push_back(maxType);
+                modeGrouped = true;
+            }
+
+            //Build message
+            QString message;
+            int indexGroup = 0;
+            for (int i = 0; i < nbMessages; ++i) {
+                QString m = msg.at(i);
+                SKGDocument::MessageType t = type.at(i);
+                if (modeGrouped) {
+                    if (t == SKGDocument::Warning) m = i18nc("Warning header", "Warning: %1", m);
+                    else if (t == SKGDocument::Error) m = i18nc("Error header", "Error: %1", m);
+                    else if (t == SKGDocument::Information) m = i18nc("Information header", "Information: %1", m);
+                    else if (t == SKGDocument::Positive) m = i18nc("Done header", "Done: %1", m);
+                }
+                if (modeGrouped || t == listGroups.at(indexGroup)) {
+                    //Same group
+                    if (!message.isEmpty()) message += "<br>";
+                    message += m;
+                } else {
+                    //Different group
+                    displayMessage(message, listGroups.at(indexGroup));
+
+                    //Reset message
+                    message = m;
+
+                    indexGroup++;
+                }
+            }
+
+            if (nbMessages < 21) {
                 //Display a simple notification
-                KNotification* notify = new KNotification(KGlobal::mainComponent().aboutData()->appName() % "_info_event" , this);
+                /*KNotification* notify = new KNotification(KGlobal::mainComponent().aboutData()->appName() % "_info_event" , this);
                 notify->setText(message);
-                notify->sendEvent();
+                notify->sendEvent();*/
+
+                displayMessage(message, listGroups.at(indexGroup));
             } else {
                 //Too many message, display a warning panel
                 KMessageBox::information(SKGMainPanel::getMainPanel(), message, i18nc("Noun",  "Notification"));
@@ -1793,22 +1832,45 @@ QLabel* SKGMainPanel::statusNormalMessage() const
     return m_kNormalMessage;
 }
 
+void SKGMainPanel::displayMessage(const QString& iMessage, SKGDocument::MessageType iType)
+{
+    KMessageWidget* msg = new KMessageWidget(this);
+    msg->setText(iMessage);
+    msg->setMessageType((KMessageWidget::MessageType) iType);
+    QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, msg, SLOT(deleteLater()));
+    m_mainLayout->insertWidget(qMax(m_mainLayout->indexOf(m_mainWidget)-1,0), msg);
+}
+
+void SKGMainPanel::displayErrorMessage(const QString& iMessage)
+{
+    QString msg = iMessage;
+    if (msg.isEmpty()) {
+        QAction* act = qobject_cast< QAction* >(sender());
+        if (act) msg = act->data().toString();
+    }
+    displayMessage(msg, SKGDocument::Error);
+}
+
 void SKGMainPanel::displayErrorMessage(const SKGError& iError)
 {
     SKGTRACEIN(1, "SKGMainPanel::displayErrorMessage");
     SKGMainPanel* parent = SKGMainPanel::getMainPanel();
     if (parent) {
         if (iError) {
-            QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-            int rc = KMessageBox::Cancel;
-            if (iError.getHistoricalSize()) rc = KMessageBox::warningContinueCancel(parent, iError.getFullMessage(),
-                                                     i18nc("Question",  "Error"),
-                                                     KStandardGuiItem::cont(),
-                                                     KGuiItem(i18nc("Noun", "History"), KIcon("dialog-information")));
-            if (rc == KMessageBox::Cancel) {
-                KMessageBox::error(parent, iError.getFullMessageWithHistorical(), i18nc("Noun", "Error"));
+            KMessageWidget* msg = new KMessageWidget(parent);
+            msg->setText(iError.getFullMessage());
+            msg->setMessageType(KMessageWidget::Error);
+            parent->m_mainLayout->insertWidget(0, msg);
+            QTimer::singleShot(20000, msg, SLOT(deleteLater()));
+
+            if (iError.getHistoricalSize()) {
+                QAction* history = new QAction(i18nc("Noun", "History"), msg);
+                history->setIcon(KIcon("dialog-information"));
+                history->setData(iError.getFullMessageWithHistorical());
+                msg->addAction(history);
+                connect(history, SIGNAL(triggered(bool)), parent, SLOT(displayErrorMessage()));
+                connect(history, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
             }
-            QApplication::restoreOverrideCursor();
         } else {
             //Status bar
             QLabel* label = parent->statusNormalMessage();
@@ -1951,8 +2013,8 @@ bool SKGMainPanel::naturalLessThan(const QString& s1, const QString& s2)
 
 bool SKGMainPanel::adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2)
 {
-    if(s1.getPriority() == s2.getPriority())
-      return (s1.getShortMessage() > s2.getShortMessage());
+    if (s1.getPriority() == s2.getPriority())
+        return (s1.getShortMessage() > s2.getShortMessage());
     return (s1.getPriority() > s2.getPriority());
 }
 
