@@ -139,6 +139,21 @@ public:
     static KConfigGroup getMainConfigGroup();
 
 public Q_SLOTS:
+
+    /**
+     * Display a message
+     * @param iMessage the message
+     * @param iType the type
+     */
+    virtual void displayMessage(const QString& iMessage, SKGDocument::MessageType iType = SKGDocument::Information);
+
+
+    /**
+     * Display an error message
+     * @param iMessage the error message. If the message is "", the data of the sender will be used
+     */
+    virtual void displayErrorMessage(const QString& iMessage = "");
+
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
@@ -493,7 +508,7 @@ private:
     KMenu* m_nextMenu;
     KMenu* m_buttonMenu;
     QWidget* m_mainWidget;
-    QHBoxLayout* m_mainLayout;
+    QVBoxLayout* m_mainLayout;
 
     struct doublePointer {
         void* p1;
