@@ -634,7 +634,8 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         if (obj && m_document) {
             if (m_doctransactionTable) {
                 QStringList msg;
-                m_document->getMessages(obj->getID(), msg);
+                QList<SKGDocument::MessageType> type;
+                m_document->getMessages(obj->getID(), msg, type);
                 int nbMessages = msg.count();
                 if (nbMessages) {
                     for (int i = 0; i < nbMessages; ++i) {
