@@ -22,7 +22,7 @@
 #include "skgtreeviewdesignerplugin.h"
 #include "skgtreeview.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
