@@ -42,6 +42,7 @@
 #include <kicon.h>
 #include <kstandardaction.h>
 #include <klocale.h>
+#include <ksavefile.h>
 
 #include "math.h"
 
@@ -162,6 +163,16 @@ void SKGWebView::exportInFile(const QString& iFileName)
         QPainter painter(&printer);
         this->render(&painter);
         painter.end();
+    } else if (extension == "HTML" || extension == "HTM") {
+        KSaveFile file(iFileName);
+        if (file.open()) {
+            QTextStream out(&file);
+            out << page()->mainFrame()->toHtml();
+        }
+
+        //Close file
+        file.finalize();
+        file.close();
     } else {
         QImage image(this->size(), QImage::Format_ARGB32);
         QPainter painter(&image);
@@ -174,7 +185,7 @@ void SKGWebView::exportInFile(const QString& iFileName)
 void SKGWebView::onExport()
 {
     _SKGTRACEIN(10, "SKGWebView::onExport");
-    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "application/pdf application/vnd.oasis.opendocument.text image/png image/jpeg image/gif image/tiff", this);
+    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "application/pdf text/html application/vnd.oasis.opendocument.text image/png image/jpeg image/gif image/tiff", this);
     if (fileName.isEmpty()) return;
 
     exportInFile(fileName);
@@ -185,15 +196,15 @@ void SKGWebView::onExport()
 void SKGWebView::onPrintPreview()
 {
     SKGTRACEIN(10, "SKGWebView::onPrintPreview");
-    QPrintPreviewDialog preview(this);
-    connect(&preview, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
-    preview.exec();
+    QPointer<QPrintPreviewDialog> dialog = new QPrintPreviewDialog(this);
+    connect(dialog, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
+    dialog->exec();
+    delete dialog;
 }
 
 void SKGWebView::onPrint()
 {
     _SKGTRACEIN(10, "SKGWebView::onPrint");
-#ifndef QT_NO_PRINTER
     QPrinter printer;
     QPointer<QPrintDialog> dialog = new QPrintDialog(&printer, this);
     if (dialog->exec() == QDialog::Accepted) {
@@ -203,6 +214,5 @@ void SKGWebView::onPrint()
     }
 
     delete dialog;
-#endif
 }
 #include "skgwebview.moc"
