@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +22,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include <QString>
+#include <qstringbuilder.h>
 #include "skgbasemodeler_export.h"
 
 #ifdef KDE4_FOUND
@@ -141,21 +142,33 @@ static const int ERR_WRITEACCESS = 10;
  */
 static const int ERR_FORCEABLE = 11;
 
+/**
+ * @var ERR_ENCRYPTION
+ * Error number
+ */
+static const int ERR_ENCRYPTION = 12;
+
 /**
  * @brief For a not modified field
  **/
 static const QString NOUPDATE = "-------";
 
+/**
+  * @var EPSILON
+  * Epsilon (for comparison)
+  */
+static const double EPSILON = 0.00001;
+
 /**
  * @def DELETECASCADE
  * Define a standard trigger for cascaded delete
  */
 #define DELETECASCADE(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
-            << QString()+"DROP TRIGGER IF EXISTS fkdc_"+TABLEPARENT+"_"+TABLECHILD+"_"+ATTPARENT+"_"+ATTCHILD \
-            << QString()+"CREATE TRIGGER fkdc_"+TABLEPARENT+"_"+TABLECHILD+"_"+ATTPARENT+"_"+ATTCHILD+" "\
-            "BEFORE DELETE ON "+TABLEPARENT+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fkdc_"%TABLEPARENT%"_"%TABLECHILD%"_"%ATTPARENT%"_"%ATTCHILD \
+            << QString()%"CREATE TRIGGER fkdc_"%TABLEPARENT%"_"%TABLECHILD%"_"%ATTPARENT%"_"%ATTCHILD%" "\
+            "BEFORE DELETE ON "%TABLEPARENT%" "\
             "FOR EACH ROW BEGIN "\
-            "    DELETE FROM "+TABLECHILD+" WHERE "+TABLECHILD+"."+ATTCHILD+" = OLD."+ATTPARENT+"; "\
+            "    DELETE FROM "%TABLECHILD%" WHERE "%TABLECHILD%"."%ATTCHILD%" = OLD."%ATTPARENT%"; "\
             "END"
 
 /**
@@ -166,19 +179,19 @@ static const QString NOUPDATE = "-------";
 
 // Should these strings be translated ??? They look far too SQLish for that purpose
 #define INSERTUPDATECONSTRAINT(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
-            << QString()+"DROP TRIGGER IF EXISTS fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT \
-            << QString()+"CREATE TRIGGER fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
-            "BEFORE INSERT ON "+TABLECHILD+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fki_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT \
+            << QString()%"CREATE TRIGGER fki_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT%" "\
+            "BEFORE INSERT ON "%TABLECHILD%" "\
             "FOR EACH ROW BEGIN "\
-            "  SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to insert object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fki_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
-            "  WHERE NEW."+ATTCHILD+"!=0 AND NEW."+ATTCHILD+"!='' AND (SELECT "+ATTPARENT+" FROM "+TABLEPARENT+" WHERE "+ATTPARENT+" = NEW."+ATTCHILD+") IS NULL; "\
+            "  SELECT RAISE(ABORT, '"%SKGServices::stringToSqlString(i18nc("Error message", "Impossible to insert object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fki_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT))%"') "\
+            "  WHERE NEW."%ATTCHILD%"!=0 AND NEW."%ATTCHILD%"!='' AND (SELECT "%ATTPARENT%" FROM "%TABLEPARENT%" WHERE "%ATTPARENT%" = NEW."%ATTCHILD%") IS NULL; "\
             "END"\
-            << QString()+"DROP TRIGGER IF EXISTS fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT \
-            << QString()+"CREATE TRIGGER fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
-            "BEFORE UPDATE ON "+TABLECHILD+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fku_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT \
+            << QString()%"CREATE TRIGGER fku_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT%" "\
+            "BEFORE UPDATE ON "%TABLECHILD%" "\
             "FOR EACH ROW BEGIN "\
-            "    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to update object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fku_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
-            "      WHERE NEW."+ATTCHILD+"!=0 AND NEW."+ATTCHILD+"!='' AND (SELECT "+ATTPARENT+" FROM "+TABLEPARENT+" WHERE "+ATTPARENT+" = NEW."+ATTCHILD+") IS NULL; "\
+            "    SELECT RAISE(ABORT, '"%SKGServices::stringToSqlString(i18nc("Error message", "Impossible to update object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fku_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT))%"') "\
+            "      WHERE NEW."%ATTCHILD%"!=0 AND NEW."%ATTCHILD%"!='' AND (SELECT "%ATTPARENT%" FROM "%TABLEPARENT%" WHERE "%ATTPARENT%" = NEW."%ATTCHILD%") IS NULL; "\
             "END"
 
 /**
@@ -187,12 +200,12 @@ static const QString NOUPDATE = "-------";
  */
 #define FOREIGNCONSTRAINT(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
     INSERTUPDATECONSTRAINT(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
-            << QString()+"DROP TRIGGER IF EXISTS fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT \
-            << QString()+"CREATE TRIGGER fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
-            "BEFORE DELETE ON "+TABLEPARENT+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fkd_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT \
+            << QString()%"CREATE TRIGGER fkd_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT%" "\
+            "BEFORE DELETE ON "%TABLEPARENT%" "\
             "FOR EACH ROW BEGIN "\
-            "    SELECT RAISE(ABORT, '"+SKGServices::stringToSqlString(i18nc("Error message", "Impossible to delete used object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT))+"') "\
-            "    WHERE (SELECT "+ATTCHILD+" FROM "+TABLECHILD+" WHERE "+ATTCHILD+" = OLD."+ATTPARENT+") IS NOT NULL; "\
+            "    SELECT RAISE(ABORT, '"%SKGServices::stringToSqlString(i18nc("Error message", "Impossible to delete used object (%1 is used by %2).\nConstraint name: %3",TABLEPARENT, TABLECHILD, "fkd_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT))%"') "\
+            "    WHERE (SELECT "%ATTCHILD%" FROM "%TABLECHILD%" WHERE "%ATTCHILD%" = OLD."%ATTPARENT%") IS NOT NULL; "\
             "END"
 
 /**
@@ -201,16 +214,16 @@ static const QString NOUPDATE = "-------";
  */
 #define FOREIGNCONSTRAINTUPDATE(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
     INSERTUPDATECONSTRAINT(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
-            << QString()+"DROP TRIGGER IF EXISTS fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT \
-            << QString()+"CREATE TRIGGER fkd_"+TABLECHILD+"_"+TABLEPARENT+"_"+ATTCHILD+"_"+ATTPARENT+" "\
-            "BEFORE DELETE ON "+TABLEPARENT+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fkd_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT \
+            << QString()%"CREATE TRIGGER fkd_"%TABLECHILD%"_"%TABLEPARENT%"_"%ATTCHILD%"_"%ATTPARENT%" "\
+            "BEFORE DELETE ON "%TABLEPARENT%" "\
             "FOR EACH ROW BEGIN "\
-            "    UPDATE "+TABLECHILD+" SET "+ATTCHILD+"=0 WHERE "+ATTCHILD+"=OLD."+ATTPARENT+"; "\
+            "    UPDATE "%TABLECHILD%" SET "%ATTCHILD%"=0 WHERE "%ATTCHILD%"=OLD."%ATTPARENT%"; "\
             "END"
 
 /**
  * @def FOREIGNCONSTRAINTCASCADE
- * Define a standard trigger for foreign constraint +cascade delete
+ * Define a standard trigger for foreign constraint cascade delete
  */
 #define FOREIGNCONSTRAINTCASCADE(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
     INSERTUPDATECONSTRAINT(TABLEPARENT,ATTPARENT,TABLECHILD,ATTCHILD)\
@@ -221,11 +234,11 @@ static const QString NOUPDATE = "-------";
  * Define a cascaded delete to delete parameters associated with an object
  */
 #define DELETECASCADEPARAMETER(TABLE) \
-            << QString()+"DROP TRIGGER IF EXISTS fkdc_"+TABLE+"_parameters_uuid" \
-            << QString()+"CREATE TRIGGER fkdc_"+TABLE+"_parameters_uuid "\
-            "BEFORE DELETE ON "+TABLE+" "\
+            << QString()%"DROP TRIGGER IF EXISTS fkdc_"%TABLE%"_parameters_uuid" \
+            << QString()%"CREATE TRIGGER fkdc_"%TABLE%"_parameters_uuid "\
+            "BEFORE DELETE ON "%TABLE%" "\
             "FOR EACH ROW BEGIN "\
-            "    DELETE FROM parameters WHERE parameters.t_uuid_parent=OLD.id||'-'||'"+TABLE+"'; "\
+            "    DELETE FROM parameters WHERE parameters.t_uuid_parent=OLD.id||'-'||'"%TABLE%"'; "\
             "END"
 
 #endif
