@@ -31,19 +31,19 @@ class SKGDocument;
  */
 class SKGBASEMODELER_EXPORT SKGNodeObject : public SKGNamedObject
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * Order of the node
      */
-    Q_PROPERTY(double order READ getOrder WRITE setOrder);
+    Q_PROPERTY(double order READ getOrder WRITE setOrder)
     /**
      * Full name of the node
      */
-    Q_PROPERTY(QString fullName READ getFullName);
+    Q_PROPERTY(QString fullName READ getFullName)
     /**
      * Data of the node
      */
-    Q_PROPERTY(QString data READ getData WRITE setData);
+    Q_PROPERTY(QString data READ getData WRITE setData)
 
 public:
 
@@ -69,7 +69,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGNodeObject(const SKGObjectBase& iObject);
+    explicit SKGNodeObject(const SKGObjectBase& iObject);
 
     /**
      * Operator affectation
