@@ -990,7 +990,7 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
             err = SKGError(SQLLITEERROR + sqlError.number(), iSqlOrder);
             err.addError(SQLLITEERROR + sqlError.number(), sqlError.text());
 
-            if (sqlError.number() == 19) err.addError(ERR_FAIL, i18nc("Error message", "Creation failed. The object already exists."));
+            if (sqlError.number() == 19 && iSqlOrder.startsWith(QLatin1String("INSERT "))) err.addError(ERR_FAIL, i18nc("Error message", "Creation failed. The object already exists."));
         } else {
             if (iLastId) *iLastId = query.lastInsertId().toInt();
         }
