@@ -112,6 +112,8 @@ public:
         QString Country;
         /** The Internet code of the unit */
         QString Internet;
+        /** The download source */
+        QString Source;
         /** The parent unit of the unit */
         QString Parent;
         /** The date of the unit */
@@ -464,7 +466,25 @@ public:
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError download(const KUrl& iSourceUrl, QString& oStream);
+    static SKGError downloadToStream(const KUrl& iSourceUrl, QByteArray& oStream);
+
+    /**
+     * Download a non local URL to a temporary file
+     * @param iSourceUrl the non local URL
+     * @param oTemporaryFile a temporary file. You have to delete it
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    static SKGError download(const KUrl& iSourceUrl, QString& oTemporaryFile);
+
+    /**
+     * Upload from a source to a destination
+     * @param iSourceUrl the source
+     * @param iDescUrl the destination
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    static SKGError upload(const KUrl& iSourceUrl, const KUrl& iDescUrl);
 
     /**
      * To enable, disable sql traces
